pecos.reps.pypmir.op\_types
===========================

.. automodule:: pecos.reps.pypmir.op_types











   .. rubric:: Classes

   .. autosummary::

      COp
      EMOp
      FFCall
      MOp
      Op
      QOp
      SOp
